#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deferred-folds
version:              0.9.18.8
visibility:           public
id:                   deferred-folds-0.9.18.8-LLWvK83zMVU2X4IKM8XnfN
key:                  deferred-folds-0.9.18.8-LLWvK83zMVU2X4IKM8XnfN
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/nikita-volkov/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  de4c1cbbb06a6489b5fab06e74fb68ba
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deferred-folds-0.9.18.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deferred-folds
hs-libraries:         HSdeferred-folds-0.9.18.8-LLWvK83zMVU2X4IKM8XnfN
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    foldl-1.4.18-DefHbEKal9W9EkQXruk2Gm
    hashable-1.4.7.0-T6DCV5EfgDB3vghPWgrCN
    primitive-0.9.1.0-1qeDM5nNzHV8hqjV1KnoQ1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-LXAzHO8zZLp8w9V0PnyDcb
    vector-0.13.2.0-91lzNiZgjgOBDn02pUIYXJ

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

